@@ -7,7 +7,7 @@
 ;; Maintainer: TRANSLATOR
 ;; Keywords: Input Method, i18n
 
-(defconst scim-bridge-XX-version "0.8.1")
+(defconst scim-bridge-XX-version "0.8.2")
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -83,7 +83,7 @@
 ;; History:
 ;; YEAR-MM-DD  TRANSLATOR
 ;;         * Initial release
-;;         * Version 0.8.1
+;;         * Version 0.8.2
 
 ;; ToDo:
 
@@ -487,6 +487,16 @@
  ;; "Make SCIM not usable with isearch-mode."
  "")
 
+(scim-set-function-doc
+ 'scim-mode-on
+ ;; "Turn scim-mode on."
+ "")
+
+(scim-set-function-doc
+ 'scim-mode-off
+ ;; "Turn scim-mode off."
+ "")
+
 (scim-set-function-doc
  'scim-mode
  ;; "Toggle SCIM minor mode (scim-mode).
