@@ -6,7 +6,7 @@
 ;; Maintainer: S. Irie
 ;; Keywords: Input Method, i18n
 
-(defconst scim-bridge-en-version "0.8.1")
+(defconst scim-bridge-en-version "0.8.2")
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -80,6 +80,10 @@
 ;;
 
 ;; History:
+;; 2010-06-26  S. Irie
+;;         * Add translations
+;;         * Version 0.8.2
+;;
 ;; 2010-05-29  S. Irie
 ;;         * Add/modify translations
 ;;         * Version 0.8.1
@@ -426,7 +430,6 @@ deactivated.")
 are deactivated when invoking these hooks.")
 
 (scim-set-variable-doc
- 'scim-undo-command-list
  'scim-preedit-incompatible-commands
  "List of symbols specifying commands which are disabled when preediting.")
 
@@ -465,6 +468,14 @@ restart scim-mode so that this settings may become effective.")
  'scim-disable-isearch
  "Make SCIM not usable with isearch-mode.")
 
+(scim-set-function-doc
+ 'scim-mode-on
+ "Turn scim-mode on.")
+
+(scim-set-function-doc
+ 'scim-mode-off
+ "Turn scim-mode off.")
+
 (scim-set-function-doc
  'scim-mode
  "Toggle SCIM minor mode (scim-mode).
